==> openshift-model-operator-4.11.2-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/DNSRecordStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface DNSRecordStatusFluent<A extends DNSRecordStatusFluent<A>> extends Fluent<A>{


    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToZones(int index,DNSZoneStatus item);
    public A setToZones(int index,DNSZoneStatus item);
    public A addToZones(DNSZoneStatus... items);
    public A addAllToZones(Collection<DNSZoneStatus> items);
    public A removeFromZones(DNSZoneStatus... items);
    public A removeAllFromZones(Collection<DNSZoneStatus> items);
    public A removeMatchingFromZones(io.fabric8.kubernetes.api.builder.Predicate<DNSZoneStatusBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildZones instead.
 * @return The buildable object.
 */
@Deprecated public List<DNSZoneStatus> getZones();
    public List<DNSZoneStatus> buildZones();
    public DNSZoneStatus buildZone(int index);
    public DNSZoneStatus buildFirstZone();
    public DNSZoneStatus buildLastZone();
    public DNSZoneStatus buildMatchingZone(io.fabric8.kubernetes.api.builder.Predicate<DNSZoneStatusBuilder> predicate);
    public Boolean hasMatchingZone(io.fabric8.kubernetes.api.builder.Predicate<DNSZoneStatusBuilder> predicate);
    public A withZones(List<DNSZoneStatus> zones);
    public A withZones(DNSZoneStatus... zones);
    public Boolean hasZones();
    public DNSRecordStatusFluent.ZonesNested<A> addNewZone();
    public DNSRecordStatusFluent.ZonesNested<A> addNewZoneLike(DNSZoneStatus item);
    public DNSRecordStatusFluent.ZonesNested<A> setNewZoneLike(int index,DNSZoneStatus item);
    public DNSRecordStatusFluent.ZonesNested<A> editZone(int index);
    public DNSRecordStatusFluent.ZonesNested<A> editFirstZone();
    public DNSRecordStatusFluent.ZonesNested<A> editLastZone();
    public DNSRecordStatusFluent.ZonesNested<A> editMatchingZone(io.fabric8.kubernetes.api.builder.Predicate<DNSZoneStatusBuilder> predicate);

    public interface ZonesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSZoneStatusFluent<DNSRecordStatusFluent.ZonesNested<N>>{

        
    public N and();    public N endZone();
}


}

==> openshift-model-operator-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/DNSRecordStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface DNSRecordStatusFluent<A extends DNSRecordStatusFluent<A>> extends Fluent<A> {


    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A addToZones(int index,DNSZoneStatus item);
    public A setToZones(int index,DNSZoneStatus item);
    public A addToZones(DNSZoneStatus... items);
    public A addAllToZones(Collection<DNSZoneStatus> items);
    public A removeFromZones(DNSZoneStatus... items);
    public A removeAllFromZones(Collection<DNSZoneStatus> items);
    public A removeMatchingFromZones(Predicate<DNSZoneStatusBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildZones instead.
 * @return The buildable object.
 */
@Deprecated public List<DNSZoneStatus> getZones();
    public List<DNSZoneStatus> buildZones();
    public DNSZoneStatus buildZone(int index);
    public DNSZoneStatus buildFirstZone();
    public DNSZoneStatus buildLastZone();
    public DNSZoneStatus buildMatchingZone(Predicate<DNSZoneStatusBuilder> predicate);
    public Boolean hasMatchingZone(Predicate<DNSZoneStatusBuilder> predicate);
    public A withZones(List<DNSZoneStatus> zones);
    public A withZones(DNSZoneStatus... zones);
    public Boolean hasZones();
    public DNSRecordStatusFluent.ZonesNested<A> addNewZone();
    public DNSRecordStatusFluent.ZonesNested<A> addNewZoneLike(DNSZoneStatus item);
    public DNSRecordStatusFluent.ZonesNested<A> setNewZoneLike(int index,DNSZoneStatus item);
    public DNSRecordStatusFluent.ZonesNested<A> editZone(int index);
    public DNSRecordStatusFluent.ZonesNested<A> editFirstZone();
    public DNSRecordStatusFluent.ZonesNested<A> editLastZone();
    public DNSRecordStatusFluent.ZonesNested<A> editMatchingZone(Predicate<DNSZoneStatusBuilder> predicate);
    public interface ZonesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DNSZoneStatusFluent<DNSRecordStatusFluent.ZonesNested<N>> {

            public N and();
            public N endZone();    }


}
